test_project/
=============

`View code on Github <https://github.com/activist-org/ts-backend-check/tree/main/src/ts_backend_check/test_project>`_

This directory contains a test pseudocode project to show people how to use ``ts-backend-check``. The project is written so that we can test all functionality of the package, with some models passing the checks and others failing them. The project is used in the following ways:

- It can be generated within the present working directory by the user for exploring functionality
- It's used during development to test package functionality
